@@ -1,7 +1,7 @@
 // qsynth.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -43,6 +43,22 @@ const WindowFlags CustomizeWindowHint   = WindowFlags(0x02000000);
 #endif
 
 
+#define CONFIG_QUOTE1(x) #x
+#define CONFIG_QUOTED(x) CONFIG_QUOTE1(x)
+
+#if defined(DATADIR)
+#define CONFIG_DATADIR CONFIG_QUOTED(DATADIR)
+#else
+#define CONFIG_DATADIR CONFIG_PREFIX "/share"
+#endif
+
+#if defined(LOCALEDIR)
+#define CONFIG_LOCALEDIR CONFIG_QUOTED(LOCALEDIR)
+#else
+#define CONFIG_LOCALEDIR CONFIG_DATADIR "/locale"
+#endif
+
+
 //-------------------------------------------------------------------------
 // Singleton application instance stuff (Qt/X11 only atm.)
 //
@@ -78,12 +94,12 @@ public:
 			} else {
 				delete m_pQtTranslator;
 				m_pQtTranslator = 0;
-		#ifdef CONFIG_DEBUG
+			#ifdef CONFIG_DEBUG
 				qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 					loc.name().toLocal8Bit().data(),
 					sLocPath.toLocal8Bit().data(),
 					sLocName.toLocal8Bit().data());
-		#endif
+			#endif
 			}
 			// Try own application translation...
 			m_pMyTranslator = new QTranslator(this);
@@ -91,18 +107,18 @@ public:
 			if (m_pMyTranslator->load(sLocName, sLocPath)) {
 				QApplication::installTranslator(m_pMyTranslator);
 			} else {
-				sLocPath = CONFIG_PREFIX "/share/locale";
+				sLocPath = CONFIG_LOCALEDIR;
 				if (m_pMyTranslator->load(sLocName, sLocPath)) {
 					QApplication::installTranslator(m_pMyTranslator);
 				} else {
 					delete m_pMyTranslator;
 					m_pMyTranslator = 0;
-		#ifdef CONFIG_DEBUG
+				#ifdef CONFIG_DEBUG
 					qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 						loc.name().toLocal8Bit().data(),
 						sLocPath.toLocal8Bit().data(),
 						sLocName.toLocal8Bit().data());
-		#endif
+				#endif
 				}
 			}
 		}
@@ -235,7 +251,9 @@ public:
 		if (pMainForm)
 			pMainForm->setQuitForce(true);
 
+	#if QT_VERSION < 0x050000
 		QApplication::commitData(sm);
+	#endif
 	}
 
 private:
@@ -265,6 +283,7 @@ private:
 #include <stdio.h>
 #include <errno.h>
 #include <signal.h>
+#include <unistd.h>
 #include <sys/wait.h>
 
 void stacktrace ( int signo )
@@ -278,7 +297,8 @@ void stacktrace ( int signo )
 	signal(signo, SIG_DFL);
 
 	static const char *shell  = "/bin/sh";
-	static const char *format = "gdb -q --batch --pid=%d --eval-command=bt";
+	static const char *format = "gdb -q --batch --pid=%d"
+		" --eval-command='thread apply all bt'";
 
 	snprintf(cmd, sizeof(cmd), format, (int) getpid());
 
@@ -345,6 +365,19 @@ int main ( int argc, char **argv )
 	// Dark themes grayed/disabled color group fix...
 	QPalette pal(app.palette());
 	if (pal.base().color().value() < 0x7f) {
+	#if QT_VERSION >= 0x050000
+		const QColor& color = pal.window().color();
+		const int iGroups = int(QPalette::Active | QPalette::Inactive) + 1;
+		for (int i = 0; i < iGroups; ++i) {
+			const QPalette::ColorGroup group = QPalette::ColorGroup(i);
+			pal.setBrush(group, QPalette::Light,    color.lighter(150));
+			pal.setBrush(group, QPalette::Midlight, color.lighter(120));
+			pal.setBrush(group, QPalette::Dark,     color.darker(150));
+			pal.setBrush(group, QPalette::Mid,      color.darker(120));
+			pal.setBrush(group, QPalette::Shadow,   color.darker(200));
+		}
+	//	pal.setColor(QPalette::Disabled, QPalette::ButtonText, pal.mid().color());
+	#endif
 		pal.setColorGroup(QPalette::Disabled,
 			pal.windowText().color().darker(),
 			pal.button(),
