@@ -1,7 +1,7 @@
 // qsynthChannelsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -72,10 +72,15 @@ qsynthChannelsForm::qsynthChannelsForm (
 
 	// Soundfonts list view...
 	QHeaderView *pHeader = m_ui.ChannelsListView->header();
-//	pHeader->setResizeMode(QHeaderView::Custom);
 	pHeader->setDefaultAlignment(Qt::AlignLeft);
 //	pHeader->setDefaultSectionSize(320);
+#if QT_VERSION >= 0x050000
+//	pHeader->setSectionResizeMode(QHeaderView::Custom);
+	pHeader->setSectionsMovable(false);
+#else
+//	pHeader->setResizeMode(QHeaderView::Custom);
 	pHeader->setMovable(false);
+#endif
 	pHeader->setStretchLastSection(true);
 
 	pHeader->resizeSection(0, 24);						// In.
