@@ -1,7 +1,7 @@
 // qsynthMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -53,6 +53,10 @@
 #include <QDragEnterEvent>
 #include <QDropEvent>
 
+#if QT_VERSION >= 0x050000
+#include <QMimeData>
+#endif
+
 #if QT_VERSION < 0x040500
 namespace Qt {
 const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
@@ -1304,8 +1308,13 @@ void qsynthMainForm::toggleMainForm (void)
 
 	if (isVisible()) {
 		if (m_pOptions->bSystemTray && m_pSystemTray) {
-			// Hide away from sight.
-			hide();
+			// Hide away from sight, if not active...
+			if (isActiveWindow()) {
+				hide();
+			} else {
+				raise();
+				activateWindow();
+			}
 		} else {
 			// Minimize (iconify) normally.
 			showMinimized();
